<?php
/**
 * Omega Commerce
 *
 * Licence: MIT https://opensource.org/licenses/MIT
 * Copyright: 2017 Omega Commerce LLC https://omegacommerce.com
 */
namespace OmegaCommerce\Controller\Admin;


class SettingController
{
    /**
     * Construct the plugin object
     */
    public function __construct(
        \OmegaCommerce\Entity\Helper\Render $renderHelper,
        \OmegaCommerce\Api\Auth $auth
    )
    {
        $this->renderHelper = $renderHelper;
        $this->auth = $auth;
    }

    /**
     *  Show settings page handler
     */
    public function showAction()
    {
        if (!current_user_can(\OmegaCommerce\Model\Menu::OMEGA_COMMERCE_CAPABILITY)) {
            wp_die(__('You do not have sufficient permissions to access this page.'));
        }
        if (!$this->auth->isAuthorized()) {
            $this->auth->register(get_site_url());
        }
        // Render the settings template
        require_once(sprintf("%ssrc/view/templates/settings.php", WP_OMEGA_COMMERCE_PLUGIN_PATH));
    }

    /**
     * @return string
     */
    public function cronLastRunMessage() {
        $time = get_option('omega_cron_last_at');
        if ($time == "") {
            return "Cron has not run yet.";
        } else {

            $seconds = gmdate('U')-$time;
            if ($seconds > 60 * 60 * 24 * 7) {
                return "Cron run long time ago. Probably it's not working. Please check cron settings.";
            } else {
                $x = $seconds / 60 / 60;
                $hours = (int)$x;
                $minutes = round(60 * ($x-$hours));
                if ($hours > 0 ) {
                    $hours = "$hours hours";
                } else {
                    $hours = "";
                }
                return "Last time cron run $hours $minutes min. ago";
            }
        }
    }
}