<?php
/**
 * Omega Commerce
 *
 * Licence: MIT https://opensource.org/licenses/MIT
 * Copyright: 2017 Omega Commerce LLC https://omegacommerce.com
 */
namespace OmegaCommerce\Model;

class Cron
{

    public function __construct(
        \OmegaCommerce\Api\Indexer $indexer,
        \OmegaCommerce\Model\Config $config
    )
    {
        $this->indexer = $indexer;
        $this->config = $config;

        add_filter('cron_schedules', array(&$this, 'add_custom_schedule'));
        add_action('omega_search_reindex', array(&$this, 'run'));

        if (!wp_next_scheduled('omega_search_reindex')) {
            wp_schedule_event(time(), 'omega_every_x_minutes', 'omega_search_reindex');
        }
    }





    public function add_custom_schedule($schedules)
    {
        $interval = get_option('omega_api_reindex_by_cron_interval');

        $schedules['omega_every_x_minutes'] = array(
            'interval' => 60 * $interval,
            'display' => __('Every '.$interval.' Minutes', 'textdomain')
        );

        return $schedules;
    }

    public function run()
    {
        if (!$this->config->isReindexByCronEnabled()) {
            return;
        }
        update_option('omega_cron_last_at', gmdate('U'));

        $limit = get_option('omega_api_max_sync_number');
        if ($limit < 1) {
            $limit = 200;
        }
        foreach ($this->indexer->getEntities() as $entity) {
            $this->indexer->refreshStatus($entity);
            $this->indexer->removeEntity($entity, $limit);
            $this->indexer->reindexEntity($entity, $limit);
        }
    }
}