<?php
/**
 * Omega Commerce
 *
 * Licence: MIT https://opensource.org/licenses/MIT
 * Copyright: 2017 Omega Commerce LLC https://omegacommerce.com
 */
namespace OmegaCommerce\Model;

class DatabaseMigration
{

    const DB_SCHEMA_VERSION = '1.1';
    const DB_DATA_VERSION = '1.2';
    const OMEGA_SYNC_STATUS_TABLE = 'omega_index_status';

    public function __construct(
        \OmegaCommerce\Api\Indexer $indexer
    )
    {
        $this->indexer = $indexer;
        add_action('plugins_loaded', array(&$this, 'updateDBCheck'));
    }


    public function updateDBCheck()
    {
        //update_option(Config::IS_ENABLED_TEMPLATE_RENDERING, false);

        $version = get_option('omega_core_db_version');
        if (version_compare($version, self::DB_SCHEMA_VERSION) == -1) {
            $this->install($version);
        }

        $version = get_option('omega_core_db_data_version');
        if (version_compare($version, self::DB_DATA_VERSION) == -1) {
            $this->installData($version);
        }
    }

    public function install($oldVersion)
    {
        global $wpdb;

        $table_name = $wpdb->prefix . self::OMEGA_SYNC_STATUS_TABLE;

        $charset_collate = $this->getCharsetCollate();

        $sql = "CREATE TABLE `$table_name` (
  `entity_id` bigint(20) NOT NULL,
  `entity_type` varchar(25) NOT NULL,
  `table_name` varchar(25) NOT NULL DEFAULT '',
  `updated_at` TIMESTAMP NOT NULL ON UPDATE CURRENT_TIMESTAMP,
  `hash` TEXT DEFAULT NULL,
  `old_hash` TEXT DEFAULT NULL,
  `is_reindexed` tinyint(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`entity_id`,`entity_type`,`table_name`)
        ) $charset_collate;";

        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        dbDelta($sql);

        update_option('omega_core_db_version', self::DB_SCHEMA_VERSION);
    }

    public function installData($oldVersion)
    {
        if ($oldVersion == "" && get_option("omega_api/is_synced")) {
            $oldVersion = "1.0";
            add_option(Config::IS_ENABLED_TEMPLATE_RENDERING, true);
        }

        if ($oldVersion == "1.0") {
            add_option(Config::NOTICE_FLAG_ASK_REINDEX, true);
        }

        if (version_compare($oldVersion, '1.2') == -1) {
            update_option('omega_api_reindex_by_cron', get_option('omega_api_sync_mode'));
            update_option('omega_api_reindex_after_save', !get_option('omega_api_sync_mode'));
        }

        update_option('omega_core_db_data_version', self::DB_DATA_VERSION);
    }

    public function getCharsetCollate()
    {
//        global $wpdb;
//        $query = "show table status like '{$wpdb->prefix}posts'";
//        $res = $wpdb->get_results($query, ARRAY_A);
//        $collation = $res[0]["Collation"];
        $collation = $this->indexer->getDBCollation();
//        $charset_collate = $wpdb->get_charset_collate();
//        $n = strpos($charset_collate,"COLLATE ", 0);
//        $r = substr($charset_collate, 0, $n);
//        return $r."COLLATE ".$collation;
        return "DEFAULT COLLATE ".$collation;
    }
}